==> nextcloud-14.0.13.zip: nextcloud/apps/files_sharing/l10n/fi.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Jaettu muiden kanssa",
    "Shared with you" : "Jaettu kanssasi",
    "Shared by link" : "Jaettu linkin kautta",
    "Deleted shares" : "Poistetut jaot",
    "Shares" : "Jaot",
    "Nothing shared with you yet" : "Kanssasi ei ole vielä jaettu mitään",
    "Files and folders others share with you will show up here" : "Kanssasi jaetut tiedostot ja kansiot näkyvät täällä",
    "Nothing shared yet" : "Ei mitään jaettua",
    "Files and folders you share will show up here" : "Jakamasi tiedostot ja kansiot näkyvät täällä",
    "No shared links" : "Ei jaettuja linkkejä",
    "Files and folders you share by link will show up here" : "Linkin kautta jakamasi tiedostot ja kansiot näkyvät täällä",
    "No deleted shares" : "Ei poistettuja jakoja",
    "Shares you deleted will show up here" : "Poistamasi jaot näkyvät täällä",
    "No shares" : "Ei jakoja",
    "Shares will show up here" : "Jaot näkyvät täällä",
    "Restore share" : "Palauta jako",
    "Something happened. Unable to restore the share." : "Jotain tapahtui. Jakoa ei kyetty palauttamaan.",
    "Move or copy" : "Siirrä tai kopioi",
    "Download" : "Lataa",
    "Delete" : "Poista",
    "You can upload into this folder" : "Voit lähettää tiedostoja tähän kansioon",
    "Terms of service" : "Käyttöehdot",
    "No compatible server found at {remote}" : "Yhteensopivaa palvelinta ei löytynyt osoitteesta {remote}",
    "Invalid server URL" : "Virheellinen palvelimen URL",
    "Failed to add the public link to your Nextcloud" : "Julkisen linkin lisääminen Nextcloudiisi epäonnistui",
    "No expiration date set" : "Ei vanhenemispäivää asetettu",
    "Shared by" : "Jakanut",
    "File shares" : "Tiedostojaot",
    "Downloaded via public link" : "Ladattu julkista linkkiä käyttäen",
    "Downloaded by {email}" : "Ladannut {email}",
    "{file} downloaded via public link" : "{file} ladattu julkisen linkin kautta",
    "{email} downloaded {file}" : "{email} latasi tiedoston {file}",
    "Shared with group {group}" : "Jaettu ryhmälle {group}",
    "Removed share for group {group}" : "Lopetettu jakaminen ryhmälle {group}",
    "{actor} shared with group {group}" : "{actor} jakoi ryhmälle {group}",
    "{actor} removed share for group {group}" : "{actor} lopetti jakamisen ryhmälle {group}",
    "You shared {file} with group {group}" : "Jaoit kohteen {file} ryhmälle {group}",
    "You removed group {group} from {file}" : "Poistit ryhmän {group} kohteen {file} käyttöoikeudet",
    "{actor} shared {file} with group {group}" : "{actor} jakoi kohteen {file} ryhmälle {group}",
    "{actor} removed group {group} from {file}" : "{actor} poisti ryhmän {group} kohteen {file} käyttöoikeudet",
    "Shared as public link" : "Jaettu julkisella linkillä",
    "Removed public link" : "Julkinen linkki poistettu",
    "Public link expired" : "Julkinen linkki vanhentui",
    "{actor} shared as public link" : "{actor} jakoi julkisena linkkinä",
    "{actor} removed public link" : "{actor} poisti julkisen linkin",
    "Public link of {actor} expired" : "Käyttäjän {actor} julkinen linkki vanheni",
    "You shared {file} as public link" : "Jaoit kohteen {file} julkisena linkkinä",
    "You removed public link for {file}" : "Poistit kohteen {file} julkisen linkin",
    "Public link expired for {file}" : "Kohteen {file} julkinen linkki vanheni",
    "{actor} shared {file} as public link" : "{actor} jakoi kohteen {file} julkisena linkkinä",
    "{actor} removed public link for {file}" : "{actor} poisti kohteen {file} julkisen linkin",
    "Public link of {actor} for {file} expired" : "Käyttäjän {actor} julkinen linkki kohteeseen {file} vanhentui",
    "{user} accepted the remote share" : "{user} hyväksyi etäjaon",
    "{user} declined the remote share" : "{user} kieltäytyi etäjaosta",
    "You received a new remote share {file} from {user}" : "Vastaanotit uuden etäjaon {file} käyttäjältä {user}",
    "{user} accepted the remote share of {file}" : "{user} hyväksyi etäjaon {file}",
    "{user} declined the remote share of {file}" : "{user} kieltäytyi etäjaosta {file}",
    "{user} unshared {file} from you" : "{user} lopetti kohteen {file} jakamisen kanssasi",
    "Shared with {user}" : "Jaettu käyttäjälle {user}",
    "Removed share for {user}" : "Poisti jaon käyttäjälle {user}",
    "You removed yourself" : "Poistit itsesi",
    "{actor} shared with {user}" : "{actor} jakoi käyttäjälle {user}",
    "{actor} removed share for {user}" : "{actor} poisti jaon käyttäjälle {user}",
    "Shared by {actor}" : "Jakanut {actor}",
    "{actor} removed share" : "{actor} lopetti jakamisen",
    "You shared {file} with {user}" : "Jaoit kohteen {file} käyttäjälle {user}",
    "You removed {user} from {file}" : "Poistit käyttäjän {user} kohteen {file} käyttöoikeudet",
    "You removed yourself from {file}" : "Poistit itsesi tiedostosta {file}",
    "{actor} shared {file} with {user}" : "{actor} jakoi kohteen {file} käyttäjälle {user}",
    "{actor} removed {user} from {file}" : "{actor} poisti käyttäjän {user} kohteen {file} käyttöoikeudet",
    "{actor} shared {file} with you" : "{actor} jakoi kohteen {file} kanssasi",
    "{actor} removed you from the share named {file}" : "{actor} poisti sinut jaosta nimeltä {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Tiedosto tai kansio, joka on jaettu sähköpostitse tai julkisen linkin kautta, on <strong>ladattu</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Tiedosto tai kansio on jaettu <strong>toiselta palvelimelta</strong>",
    "A file or folder has been <strong>shared</strong>" : "Tiedosto tai kansio on <strong>jaettu</strong>",
    "Wrong share ID, share doesn't exist" : "Väärä jakotunniste, jakoa ei ole olemassa",
    "could not delete share" : "jaon poistaminen epäonnistui",
    "Could not delete share" : "Jaon poistaminen epäonnistui",
    "Please specify a file or folder path" : "Määritä tiedoston tai kansion polku",
    "Wrong path, file/folder doesn't exist" : "Väärä polku, tiedostoa tai kansiota ei ole olemassa",
    "Could not create share" : "Jaon luominen epäonnistui",
    "invalid permissions" : "vialliset oikeudet",
    "Please specify a valid user" : "Määritä kelvollinen käyttäjä",
    "Group sharing is disabled by the administrator" : "Ylläpitäjä on estänyt ryhmäjakamisen",
    "Please specify a valid group" : "Määritä kelvollinen ryhmä",
    "Public link sharing is disabled by the administrator" : "Ylläpitäjä on estänyt julkisen linkin jakamisen",
    "Public upload disabled by the administrator" : "Ylläpitäjä on estänyt julkisen lähetyksen",
    "Public upload is only possible for publicly shared folders" : "Julkinen lähettäminen on mahdollista vain julkisesti jaetuille kansioille",
    "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päiväys, päivämäärän muodon tulee olla VVVV-KK-PP",
    "You cannot share to a Circle if the app is not enabled" : "Et voi jakaa piiriin, jos sovellusta ei ole aktivoitu",
    "Please specify a valid circle" : "Määritä kelvollinen piiri",
    "Unknown share type" : "Tuntematon jaon tyyppi",
    "Not a directory" : "Ei hakemisto",
    "Could not lock path" : "Polun lukitseminen ei onnistunut",
    "Wrong or no update parameter given" : "Päivitettävä parametri puuttuu tai on väärin",
    "Can't change permissions for public share links" : "Julkisten jakolinkkien käyttöoikeuksia ei voi muuttaa",
    "shared by %s" : "%s jakama",
    "Download all files" : "Lataa kaikki tiedostot",
    "Direct link" : "Suora linkki",
    "Add to your Nextcloud" : "Lisää Nextcloudiisi",
    "Share API is disabled" : "Jakamisrajapinta on poistettu käytöstä",
    "File sharing" : "Tiedostonjako",
    "Link to a file" : "Linkki tiedostoon",
    "Shared" : "Jaettu",
    "Share" : "Jaa",
    "Sharing" : "Jakaminen",
    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
    "Name" : "Nimi",
    "Share time" : "Jakamisen ajankohta",
    "Expiration date" : "Vanhenemispäivä",
    "Sorry, this link doesn’t seem to work anymore." : "Valitettavasti linkki ei vaikuta enää toimivan.",
    "Reasons might be:" : "Mahdollisia syitä saattavat olla:",
    "the item was removed" : "kohde poistettiin",
    "the link expired" : "linkki vanheni",
    "sharing is disabled" : "jakaminen on poistettu käytöstä",
    "For more info, please ask the person who sent this link." : "Kysy lisätietoja henkilöltä, jolta sait linkin.",
    "Share note" : "Jaa muistiinpano",
    "Download %s" : "Lataa %s",
    "Upload files to %s" : "Lähetä tiedostoja käyttäjälle %s",
    "Select or drop files" : "Valitse tai pudota tiedostoja",
    "Uploading files…" : "Lähetetään tiedostoja…",
    "Uploaded files:" : "Lähetetyt tiedostot:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Tiedostoja lähettämällä hyväksyt %1$skäyttöehdot%2$s.",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Kohteen %s jakaminen epäonnistui, koska tietovarasto ei salli %s tyyppisiä jakoja"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.0.zip: nextcloud/apps/files_sharing/l10n/fi.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Jaettu muiden kanssa",
    "Shared with you" : "Jaettu kanssasi",
    "Shared by link" : "Jaettu linkin kautta",
    "Deleted shares" : "Poistetut jaot",
    "Shares" : "Jaot",
    "Nothing shared with you yet" : "Kanssasi ei ole vielä jaettu mitään",
    "Files and folders others share with you will show up here" : "Kanssasi jaetut tiedostot ja kansiot näkyvät täällä",
    "Nothing shared yet" : "Ei mitään jaettua",
    "Files and folders you share will show up here" : "Jakamasi tiedostot ja kansiot näkyvät täällä",
    "No shared links" : "Ei jaettuja linkkejä",
    "Files and folders you share by link will show up here" : "Linkin kautta jakamasi tiedostot ja kansiot näkyvät täällä",
    "No deleted shares" : "Ei poistettuja jakoja",
    "Shares you deleted will show up here" : "Poistamasi jaot näkyvät täällä",
    "No shares" : "Ei jakoja",
    "Shares will show up here" : "Jaot näkyvät täällä",
    "Restore share" : "Palauta jako",
    "Something happened. Unable to restore the share." : "Jotain tapahtui. Jakoa ei kyetty palauttamaan.",
    "Move or copy" : "Siirrä tai kopioi",
    "Download" : "Lataa",
    "Delete" : "Poista",
    "You can upload into this folder" : "Voit lähettää tiedostoja tähän kansioon",
    "Terms of service" : "Käyttöehdot",
    "No compatible server found at {remote}" : "Yhteensopivaa palvelinta ei löytynyt osoitteesta {remote}",
    "Invalid server URL" : "Virheellinen palvelimen URL",
    "Failed to add the public link to your Nextcloud" : "Julkisen linkin lisääminen Nextcloudiisi epäonnistui",
    "Share" : "Jaa",
    "No expiration date set" : "Ei vanhenemispäivää asetettu",
    "Shared by" : "Jakanut",
    "Sharing" : "Jakaminen",
    "File shares" : "Tiedostojaot",
    "Downloaded via public link" : "Ladattu julkista linkkiä käyttäen",
    "Downloaded by {email}" : "Ladannut {email}",
    "{file} downloaded via public link" : "{file} ladattu julkisen linkin kautta",
    "{email} downloaded {file}" : "{email} latasi tiedoston {file}",
    "Shared with group {group}" : "Jaettu ryhmälle {group}",
    "Removed share for group {group}" : "Lopetettu jakaminen ryhmälle {group}",
    "{actor} shared with group {group}" : "{actor} jakoi ryhmälle {group}",
    "{actor} removed share for group {group}" : "{actor} lopetti jakamisen ryhmälle {group}",
    "You shared {file} with group {group}" : "Jaoit kohteen {file} ryhmälle {group}",
    "You removed group {group} from {file}" : "Poistit ryhmän {group} kohteen {file} käyttöoikeudet",
    "{actor} shared {file} with group {group}" : "{actor} jakoi kohteen {file} ryhmälle {group}",
    "{actor} removed group {group} from {file}" : "{actor} poisti ryhmän {group} kohteen {file} käyttöoikeudet",
    "Shared as public link" : "Jaettu julkisella linkillä",
    "Removed public link" : "Julkinen linkki poistettu",
    "Public link expired" : "Julkinen linkki vanhentui",
    "{actor} shared as public link" : "{actor} jakoi julkisena linkkinä",
    "{actor} removed public link" : "{actor} poisti julkisen linkin",
    "Public link of {actor} expired" : "Käyttäjän {actor} julkinen linkki vanheni",
    "You shared {file} as public link" : "Jaoit kohteen {file} julkisena linkkinä",
    "You removed public link for {file}" : "Poistit kohteen {file} julkisen linkin",
    "Public link expired for {file}" : "Kohteen {file} julkinen linkki vanheni",
    "{actor} shared {file} as public link" : "{actor} jakoi kohteen {file} julkisena linkkinä",
    "{actor} removed public link for {file}" : "{actor} poisti kohteen {file} julkisen linkin",
    "Public link of {actor} for {file} expired" : "Käyttäjän {actor} julkinen linkki kohteeseen {file} vanhentui",
    "{user} accepted the remote share" : "{user} hyväksyi etäjaon",
    "{user} declined the remote share" : "{user} kieltäytyi etäjaosta",
    "You received a new remote share {file} from {user}" : "Vastaanotit uuden etäjaon {file} käyttäjältä {user}",
    "{user} accepted the remote share of {file}" : "{user} hyväksyi etäjaon {file}",
    "{user} declined the remote share of {file}" : "{user} kieltäytyi etäjaosta {file}",
    "{user} unshared {file} from you" : "{user} lopetti kohteen {file} jakamisen kanssasi",
    "Shared with {user}" : "Jaettu käyttäjälle {user}",
    "Removed share for {user}" : "Poisti jaon käyttäjälle {user}",
    "You removed yourself" : "Poistit itsesi",
    "{actor} shared with {user}" : "{actor} jakoi käyttäjälle {user}",
    "{actor} removed share for {user}" : "{actor} poisti jaon käyttäjälle {user}",
    "Shared by {actor}" : "Jakanut {actor}",
    "{actor} removed share" : "{actor} lopetti jakamisen",
    "You shared {file} with {user}" : "Jaoit kohteen {file} käyttäjälle {user}",
    "You removed {user} from {file}" : "Poistit käyttäjän {user} kohteen {file} käyttöoikeudet",
    "You removed yourself from {file}" : "Poistit itsesi tiedostosta {file}",
    "{actor} shared {file} with {user}" : "{actor} jakoi kohteen {file} käyttäjälle {user}",
    "{actor} removed {user} from {file}" : "{actor} poisti käyttäjän {user} kohteen {file} käyttöoikeudet",
    "{actor} shared {file} with you" : "{actor} jakoi kohteen {file} kanssasi",
    "{actor} removed you from the share named {file}" : "{actor} poisti sinut jaosta nimeltä {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Tiedosto tai kansio, joka on jaettu sähköpostitse tai julkisen linkin kautta, on <strong>ladattu</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Tiedosto tai kansio on jaettu <strong>toiselta palvelimelta</strong>",
    "A file or folder has been <strong>shared</strong>" : "Tiedosto tai kansio on <strong>jaettu</strong>",
    "Wrong share ID, share doesn't exist" : "Väärä jakotunniste, jakoa ei ole olemassa",
    "could not delete share" : "jaon poistaminen epäonnistui",
    "Could not delete share" : "Jaon poistaminen epäonnistui",
    "Please specify a file or folder path" : "Määritä tiedoston tai kansion polku",
    "Wrong path, file/folder doesn't exist" : "Väärä polku, tiedostoa tai kansiota ei ole olemassa",
    "Could not create share" : "Jaon luominen epäonnistui",
    "invalid permissions" : "vialliset oikeudet",
    "Please specify a valid user" : "Määritä kelvollinen käyttäjä",
    "Group sharing is disabled by the administrator" : "Ylläpitäjä on estänyt ryhmäjakamisen",
    "Please specify a valid group" : "Määritä kelvollinen ryhmä",
    "Public link sharing is disabled by the administrator" : "Ylläpitäjä on estänyt julkisen linkin jakamisen",
    "Public upload disabled by the administrator" : "Ylläpitäjä on estänyt julkisen lähetyksen",
    "Public upload is only possible for publicly shared folders" : "Julkinen lähettäminen on mahdollista vain julkisesti jaetuille kansioille",
    "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päiväys, päivämäärän muodon tulee olla VVVV-KK-PP",
    "You cannot share to a Circle if the app is not enabled" : "Et voi jakaa piiriin, jos sovellusta ei ole aktivoitu",
    "Please specify a valid circle" : "Määritä kelvollinen piiri",
    "Unknown share type" : "Tuntematon jaon tyyppi",
    "Not a directory" : "Ei hakemisto",
    "Could not lock path" : "Polun lukitseminen ei onnistunut",
    "Wrong or no update parameter given" : "Päivitettävä parametri puuttuu tai on väärin",
    "Can't change permissions for public share links" : "Julkisten jakolinkkien käyttöoikeuksia ei voi muuttaa",
    "Cannot increase permissions" : "Oikeuksien lisääminen ei onnistu",
    "shared by %s" : "%s jakama",
    "Download all files" : "Lataa kaikki tiedostot",
    "Direct link" : "Suora linkki",
    "Add to your Nextcloud" : "Lisää Nextcloudiisi",
    "Share API is disabled" : "Jakamisrajapinta on poistettu käytöstä",
    "File sharing" : "Tiedostonjako",
    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
    "Name" : "Nimi",
    "Share time" : "Jakamisen ajankohta",
    "Expiration date" : "Vanhenemispäivä",
    "Sorry, this link doesn’t seem to work anymore." : "Valitettavasti linkki ei vaikuta enää toimivan.",
    "Reasons might be:" : "Mahdollisia syitä saattavat olla:",
    "the item was removed" : "kohde poistettiin",
    "the link expired" : "linkki vanheni",
    "sharing is disabled" : "jakaminen on poistettu käytöstä",
    "For more info, please ask the person who sent this link." : "Kysy lisätietoja henkilöltä, jolta sait linkin.",
    "Share note" : "Jaa muistiinpano",
    "Download %s" : "Lataa %s",
    "Upload files to %s" : "Lähetä tiedostoja käyttäjälle %s",
    "Select or drop files" : "Valitse tai pudota tiedostoja",
    "Uploading files…" : "Lähetetään tiedostoja…",
    "Uploaded files:" : "Lähetetyt tiedostot:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Tiedostoja lähettämällä hyväksyt %1$skäyttöehdot%2$s.",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Kohteen %s jakaminen epäonnistui, koska tietovarasto ei salli %s tyyppisiä jakoja",
    "This share is password-protected" : "Tämä jako on suojattu salasanalla",
    "The password is wrong. Try again." : "Väärä salasana. Yritä uudelleen.",
    "Password" : "Salasana"
},
"nplurals=2; plural=(n != 1);");
